

#ifndef SBK_KWIDGETSADDONS_PYTHON_H
#define SBK_KWIDGETSADDONS_PYTHON_H

//workaround to access protected functions
#define protected public

#include <sbkpython.h>
#include <sbkmodule.h>
#include <sbkconverter.h>
// Module Includes
#include <pyside6_qtwidgets_python.h>
#include <pyside6_qtgui_python.h>
#include <pyside6_qtcore_python.h>

// Bound library includes
#include <kacceleratormanager.h>
#include <kactionmenu.h>
#include <kactionselector.h>
#include <kanimatedbutton.h>
#include <kassistantdialog.h>
#include <kbusyindicatorwidget.h>
#include <kcapacitybar.h>
#include <kcharselect.h>
#include <kcollapsiblegroupbox.h>
#include <kcolorbutton.h>
#include <kcolorcombo.h>
#include <kcolumnresizer.h>
#include <kcontextualhelpbutton.h>
#include <kcursor.h>
#include <kdatecombobox.h>
#include <kdatepicker.h>
#include <kdatepickerpopup.h>
#include <kdatetimeedit.h>
#include <kdragwidgetdecorator.h>
#include <kdualaction.h>
#include <keditlistwidget.h>
#include <kfontaction.h>
#include <kfontchooser.h>
#include <kfontchooserdialog.h>
#include <kfontrequester.h>
#include <kfontsizeaction.h>
#include <kguiitem.h>
#include <kjobwidgets.h>
#include <kled.h>
#include <klineediteventhandler.h>
#include <klineediturldropeventfilter.h>
#include <kmessagebox.h>
#include <kmessageboxnotifyinterface.h>
#include <kmessagedialog.h>
#include <kmessagewidget.h>
#include <kmimetypechooser.h>
#include <kmimetypeeditor.h>
#include <kmultitabbar.h>
#include <knewpassworddialog.h>
#include <knewpasswordwidget.h>
#include <kpagedialog.h>
#include <kpagemodel.h>
#include <kpageview.h>
#include <kpagewidget.h>
#include <kpagewidgetmodel.h>
#include <kpassword.h>
#include <kpassworddialog.h>
#include <kpasswordlineedit.h>
#include <kpixmapregionselectordialog.h>
#include <kpixmapregionselectorwidget.h>
#include <kpixmapsequence.h>
#include <kpixmapsequenceoverlaypainter.h>
#include <kpixmapsequencewidget.h>
#include <kpopupframe.h>
#include <kratingpainter.h>
#include <kratingwidget.h>
#include <krecentfilesmenu.h>
#include <kruler.h>
#include <kselectaction.h>
#include <kselector.h>
#include <kseparator.h>
#include <ksplittercollapserbutton.h>
#include <ksqueezedtextlabel.h>
#include <kstandardguiitem.h>
#include <kstyleextensions.h>
#include <ktimecombobox.h>
#include <ktitlewidget.h>
#include <ktoggleaction.h>
#include <ktogglefullscreenaction.h>
#include <ktoolbarlabelaction.h>
#include <ktoolbarpopupaction.h>
#include <ktoolbarspaceraction.h>
#include <ktooltipwidget.h>
#include <ktwofingerswipe.h>
#include <ktwofingertap.h>
#include <kurllabel.h>
#include <kviewstateserializer.h>
#include <kxyselector.h>
// Conversion Includes - Primitive Types
#include <QAnyStringView>
#include <qbytearrayview.h>
#include <qchar.h>
#include <QtCore/qlatin1stringview.h>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <qvariant.h>

// Conversion Includes - Container Types
#include <QHash>
#include <QList>
#include <QMap>
#include <QMultiHash>
#include <QMultiMap>
#include <QPair>
#include <QQueue>
#include <QSet>
#include <QStack>
#include <array>
#include <list>
#include <map>
#include <utility>
#include <unordered_map>
#include <vector>


// Type indices
enum : int {
    SBK_KAcceleratorManager_IDX                              = 1,
    SBK_KActionMenu_IDX                                      = 2,
    SBK_KActionSelector_MoveButton_IDX                       = 5,
    SBK_KActionSelector_InsertionPolicy_IDX                  = 4,
    SBK_KActionSelector_IDX                                  = 3,
    SBK_KAnimatedButton_IDX                                  = 6,
    SBK_KAssistantDialog_IDX                                 = 7,
    SBK_KBusyIndicatorWidget_IDX                             = 8,
    SBK_KCapacityBar_DrawTextMode_IDX                        = 10,
    SBK_KCapacityBar_IDX                                     = 9,
    SBK_KCharSelect_Control_IDX                              = 12,
    SBK_QFlags_KCharSelect_Control_IDX                       = 128,
    SBK_KCharSelect_IDX                                      = 11,
    SBK_KCollapsibleGroupBox_IDX                             = 13,
    SBK_KColorButton_IDX                                     = 14,
    SBK_KColorCombo_IDX                                      = 15,
    SBK_KColumnResizer_IDX                                   = 16,
    SBK_KContextualHelpButton_IDX                            = 17,
    SBK_KCursor_IDX                                          = 18,
    SBK_KDateComboBox_Option_IDX                             = 20,
    SBK_QFlags_KDateComboBox_Option_IDX                      = 129,
    SBK_KDateComboBox_IDX                                    = 19,
    SBK_KDatePicker_IDX                                      = 21,
    SBK_KDatePickerPopup_Mode_IDX                            = 23,
    SBK_QFlags_KDatePickerPopup_Mode_IDX                     = 130,
    SBK_KDatePickerPopup_IDX                                 = 22,
    SBK_KDateTimeEdit_Option_IDX                             = 25,
    SBK_QFlags_KDateTimeEdit_Option_IDX                      = 131,
    SBK_KDateTimeEdit_IDX                                    = 24,
    SBK_KDragWidgetDecoratorBase_IDX                         = 26,
    SBK_KDualAction_IDX                                      = 27,
    SBK_KEditListWidget_Button_IDX                           = 29,
    SBK_QFlags_KEditListWidget_Button_IDX                    = 132,
    SBK_KEditListWidget_IDX                                  = 28,
    SBK_KFontAction_IDX                                      = 30,
    SBK_KFontChooser_FontColumn_IDX                          = 33,
    SBK_KFontChooser_FontDiff_IDX                            = 34,
    SBK_QFlags_KFontChooser_FontDiff_IDX                     = 134,
    SBK_KFontChooser_DisplayFlag_IDX                         = 32,
    SBK_QFlags_KFontChooser_DisplayFlag_IDX                  = 133,
    SBK_KFontChooser_FontListCriteria_IDX                    = 35,
    SBK_KFontChooser_IDX                                     = 31,
    SBK_KFontChooserDialog_IDX                               = 36,
    SBK_KFontRequester_IDX                                   = 37,
    SBK_KFontSizeAction_IDX                                  = 38,
    SBK_KGradientSelector_IDX                                = 39,
    SBK_KGuiItem_IDX                                         = 40,
    SBK_KWidgetsAddonsKJobWidgets_IDX                        = 41,
    SBK_KLed_State_IDX                                       = 45,
    SBK_KLed_Shape_IDX                                       = 44,
    SBK_KLed_Look_IDX                                        = 43,
    SBK_KLed_IDX                                             = 42,
    SBK_KWidgetsAddonsKLineEditEventHandler_IDX              = 46,
    SBK_KLineEditUrlDropEventFilter_IDX                      = 47,
    SBK_KMessageBox_ButtonCode_IDX                           = 49,
    SBK_KMessageBox_DialogType_IDX                           = 50,
    SBK_KMessageBox_Option_IDX                               = 51,
    SBK_QFlags_KMessageBox_Option_IDX                        = 135,
    SBK_KWidgetsAddonsKMessageBox_IDX                        = 48,
    SBK_KMessageBoxNotifyInterface_IDX                       = 52,
    SBK_KMessageDialog_ButtonType_IDX                        = 54,
    SBK_KMessageDialog_Type_IDX                              = 55,
    SBK_KMessageDialog_IDX                                   = 53,
    SBK_KMessageWidget_MessageType_IDX                       = 57,
    SBK_KMessageWidget_Position_IDX                          = 58,
    SBK_KMessageWidget_IDX                                   = 56,
    SBK_KMimeTypeChooser_Visuals_IDX                         = 60,
    SBK_KMimeTypeChooser_IDX                                 = 59,
    SBK_KMimeTypeChooserDialog_IDX                           = 61,
    SBK_KWidgetsAddonsKMimeTypeEditor_IDX                    = 62,
    SBK_KMultiTabBar_KMultiTabBarPosition_IDX                = 64,
    SBK_KMultiTabBar_KMultiTabBarStyle_IDX                   = 65,
    SBK_KMultiTabBar_IDX                                     = 63,
    SBK_KMultiTabBarButton_IDX                               = 66,
    SBK_KMultiTabBarTab_IDX                                  = 67,
    SBK_KNewPasswordDialog_IDX                               = 68,
    SBK_KNewPasswordWidget_PasswordStatus_IDX                = 70,
    SBK_KNewPasswordWidget_RevealPasswordMode_IDX            = 71,
    SBK_KNewPasswordWidget_IDX                               = 69,
    SBK_KPageDialog_FaceType_IDX                             = 73,
    SBK_KPageDialog_IDX                                      = 72,
    SBK_KPageModel_Role_IDX                                  = 75,
    SBK_KPageModel_IDX                                       = 74,
    SBK_KPageView_FaceType_IDX                               = 77,
    SBK_KPageView_IDX                                        = 76,
    SBK_KPageWidget_IDX                                      = 78,
    SBK_KPageWidgetItem_IDX                                  = 79,
    SBK_KPageWidgetModel_IDX                                 = 80,
    SBK_KPassword_RevealMode_IDX                             = 82,
    SBK_KWidgetsAddonsKPassword_IDX                          = 81,
    SBK_KPasswordDialog_KPasswordDialogFlag_IDX              = 85,
    SBK_QFlags_KPasswordDialog_KPasswordDialogFlag_IDX       = 136,
    SBK_KPasswordDialog_ErrorType_IDX                        = 84,
    SBK_KPasswordDialog_IDX                                  = 83,
    SBK_KPasswordLineEdit_IDX                                = 86,
    SBK_KPixmapRegionSelectorDialog_IDX                      = 87,
    SBK_KPixmapRegionSelectorWidget_RotateDirection_IDX      = 89,
    SBK_KPixmapRegionSelectorWidget_IDX                      = 88,
    SBK_KPixmapSequence_IDX                                  = 90,
    SBK_KPixmapSequenceOverlayPainter_IDX                    = 91,
    SBK_KPixmapSequenceWidget_IDX                            = 92,
    SBK_KPopupFrame_IDX                                      = 93,
    SBK_KRatingPainter_IDX                                   = 94,
    SBK_KRatingWidget_IDX                                    = 95,
    SBK_KRecentFilesMenu_IDX                                 = 96,
    SBK_KRuler_MetricStyle_IDX                               = 98,
    SBK_KRuler_IDX                                           = 97,
    SBK_KSelectAction_ToolBarMode_IDX                        = 100,
    SBK_KSelectAction_IDX                                    = 99,
    SBK_KSelector_IDX                                        = 101,
    SBK_KSeparator_IDX                                       = 102,
    SBK_KSplitterCollapserButton_IDX                         = 103,
    SBK_KSqueezedTextLabel_IDX                               = 104,
    SBK_KStandardGuiItem_BidiMode_IDX                        = 106,
    SBK_KStandardGuiItem_StandardItem_IDX                    = 107,
    SBK_KWidgetsAddonsKStandardGuiItem_IDX                   = 105,
    SBK_KWidgetsAddonsKStyleExtensions_IDX                   = 108,
    SBK_KTimeComboBox_Option_IDX                             = 110,
    SBK_QFlags_KTimeComboBox_Option_IDX                      = 137,
    SBK_KTimeComboBox_IDX                                    = 109,
    SBK_KTitleWidget_ImageAlignment_IDX                      = 112,
    SBK_KTitleWidget_MessageType_IDX                         = 113,
    SBK_KTitleWidget_IDX                                     = 111,
    SBK_KToggleAction_IDX                                    = 114,
    SBK_KToggleFullScreenAction_IDX                          = 115,
    SBK_KToolBarLabelAction_IDX                              = 116,
    SBK_KToolBarPopupAction_PopupMode_IDX                    = 118,
    SBK_KToolBarPopupAction_IDX                              = 117,
    SBK_KToolBarSpacerAction_IDX                             = 119,
    SBK_KToolTipWidget_IDX                                   = 120,
    SBK_KTwoFingerSwipe_IDX                                  = 121,
    SBK_KTwoFingerSwipeRecognizer_IDX                        = 122,
    SBK_KTwoFingerTap_IDX                                    = 123,
    SBK_KTwoFingerTapRecognizer_IDX                          = 124,
    SBK_KUrlLabel_IDX                                        = 125,
    SBK_KViewStateSerializer_IDX                             = 126,
    SBK_KXYSelector_IDX                                      = 127,
    SBK_KWidgetsAddons_IDX_COUNT                             = 138,
};

// This variable stores all Python types exported by this module.
extern Shiboken::Module::TypeInitStruct *SbkKWidgetsAddonsTypeStructs;

// This variable stores the Python module object exported by this module.
extern PyObject *SbkKWidgetsAddonsModuleObject;

// This variable stores all type converters exported by this module.
extern SbkConverter **SbkKWidgetsAddonsTypeConverters;

// Converter indices
enum [[deprecated]] : int {
    SBK_KWIDGETSADDONS_QLIST_INT_IDX                         = 0, // QList<int>
    SBK_KWIDGETSADDONS_STD_PAIR_INT_INT_IDX                  = 1, // std::pair<int,int>
    SBK_KWIDGETSADDONS_QLIST_QTIME_IDX                       = 2, // QList<QTime>
    SBK_KWIDGETSADDONS_STD_PAIR_KGUIITEM_KGUIITEM_IDX        = 3, // std::pair<KGuiItem,KGuiItem>
    SBK_KWIDGETSADDONS_QLIST_QACTIONPTR_IDX                  = 4, // QList<QAction*>
    SBK_KWIDGETSADDONS_QLIST_QURL_IDX                        = 5, // QList<QUrl>
    SBK_KWIDGETSADDONS_QMAP_QSTRING_QSTRING_IDX              = 6, // QMap<QString,QString>
    SBK_KWIDGETSADDONS_QMAP_INT_QVARIANT_IDX                 = 7, // QMap<int,QVariant>
    SBK_KWIDGETSADDONS_QLIST_QMODELINDEX_IDX                 = 8, // QList<QModelIndex>
    SBK_KWIDGETSADDONS_QHASH_INT_QBYTEARRAY_IDX              = 9, // QHash<int,QByteArray>
    SBK_KWIDGETSADDONS_STD_PAIR_QREAL_QCOLOR_IDX             = 10, // std::pair<qreal,QColor>
    SBK_KWIDGETSADDONS_QLIST_STD_PAIR_QREAL_QCOLOR_IDX       = 11, // QList<std::pair<qreal,QColor>>
    SBK_KWIDGETSADDONS_QLIST_QLOCALE_IDX                     = 12, // QList<QLocale>
    SBK_KWIDGETSADDONS_QMAP_QDATE_QSTRING_IDX                = 13, // QMap<QDate,QString>
    SBK_KWIDGETSADDONS_QLIST_QTIMEZONE_IDX                   = 14, // QList<QTimeZone>
    SBK_KWIDGETSADDONS_QLIST_QCOLOR_IDX                      = 15, // QList<QColor>
    SBK_KWIDGETSADDONS_QLIST_QCHAR_IDX                       = 16, // QList<QChar>
    SBK_KWIDGETSADDONS_QLIST_UINT_IDX                        = 17, // QList<uint>
    SBK_KWIDGETSADDONS_QLIST_QVARIANT_IDX                    = 18, // QList<QVariant>
    SBK_KWIDGETSADDONS_QLIST_QSTRING_IDX                     = 19, // QList<QString>
    SBK_KWIDGETSADDONS_QMAP_QSTRING_QVARIANT_IDX             = 20, // QMap<QString,QVariant>
    SBK_KWIDGETSADDONS_CONVERTERS_IDX_COUNT                  = 21,
};

// Converter indices
enum : int {
    SBK_KWidgetsAddons_QList_int_IDX                         = 0, // QList<int>
    SBK_KWidgetsAddons_std_pair_int_int_IDX                  = 1, // std::pair<int,int>
    SBK_KWidgetsAddons_QList_QTime_IDX                       = 2, // QList<QTime>
    SBK_KWidgetsAddons_std_pair_KGuiItem_KGuiItem_IDX        = 3, // std::pair<KGuiItem,KGuiItem>
    SBK_KWidgetsAddons_QList_QActionPTR_IDX                  = 4, // QList<QAction*>
    SBK_KWidgetsAddons_QList_QUrl_IDX                        = 5, // QList<QUrl>
    SBK_KWidgetsAddons_QMap_QString_QString_IDX              = 6, // QMap<QString,QString>
    SBK_KWidgetsAddons_QMap_int_QVariant_IDX                 = 7, // QMap<int,QVariant>
    SBK_KWidgetsAddons_QList_QModelIndex_IDX                 = 8, // QList<QModelIndex>
    SBK_KWidgetsAddons_QHash_int_QByteArray_IDX              = 9, // QHash<int,QByteArray>
    SBK_KWidgetsAddons_std_pair_qreal_QColor_IDX             = 10, // std::pair<qreal,QColor>
    SBK_KWidgetsAddons_QList_std_pair_qreal_QColor_IDX       = 11, // QList<std::pair<qreal,QColor>>
    SBK_KWidgetsAddons_QList_QLocale_IDX                     = 12, // QList<QLocale>
    SBK_KWidgetsAddons_QMap_QDate_QString_IDX                = 13, // QMap<QDate,QString>
    SBK_KWidgetsAddons_QList_QTimeZone_IDX                   = 14, // QList<QTimeZone>
    SBK_KWidgetsAddons_QList_QColor_IDX                      = 15, // QList<QColor>
    SBK_KWidgetsAddons_QList_QChar_IDX                       = 16, // QList<QChar>
    SBK_KWidgetsAddons_QList_uint_IDX                        = 17, // QList<uint>
    SBK_KWidgetsAddons_QList_QVariant_IDX                    = 18, // QList<QVariant>
    SBK_KWidgetsAddons_QList_QString_IDX                     = 19, // QList<QString>
    SBK_KWidgetsAddons_QMap_QString_QVariant_IDX             = 20, // QMap<QString,QVariant>
    SBK_KWidgetsAddons_CONVERTERS_IDX_COUNT                  = 21,
};
// Macros for type check

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject *SbkType< ::KAcceleratorManager >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KAcceleratorManager_IDX]); }
template<> inline PyTypeObject *SbkType< ::KActionMenu >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KActionMenu_IDX]); }
template<> inline PyTypeObject *SbkType< ::KActionSelector::MoveButton >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KActionSelector_MoveButton_IDX]); }
template<> inline PyTypeObject *SbkType< ::KActionSelector::InsertionPolicy >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KActionSelector_InsertionPolicy_IDX]); }
template<> inline PyTypeObject *SbkType< ::KActionSelector >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KActionSelector_IDX]); }
template<> inline PyTypeObject *SbkType< ::KAnimatedButton >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KAnimatedButton_IDX]); }
template<> inline PyTypeObject *SbkType< ::KAssistantDialog >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KAssistantDialog_IDX]); }
template<> inline PyTypeObject *SbkType< ::KBusyIndicatorWidget >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KBusyIndicatorWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::KCapacityBar::DrawTextMode >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KCapacityBar_DrawTextMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::KCapacityBar >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KCapacityBar_IDX]); }
template<> inline PyTypeObject *SbkType< ::KCharSelect::Control >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KCharSelect_Control_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KCharSelect::Control> >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_QFlags_KCharSelect_Control_IDX]); }
template<> inline PyTypeObject *SbkType< ::KCharSelect >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KCharSelect_IDX]); }
template<> inline PyTypeObject *SbkType< ::KCollapsibleGroupBox >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KCollapsibleGroupBox_IDX]); }
template<> inline PyTypeObject *SbkType< ::KColorButton >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KColorButton_IDX]); }
template<> inline PyTypeObject *SbkType< ::KColorCombo >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KColorCombo_IDX]); }
template<> inline PyTypeObject *SbkType< ::KColumnResizer >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KColumnResizer_IDX]); }
template<> inline PyTypeObject *SbkType< ::KContextualHelpButton >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KContextualHelpButton_IDX]); }
template<> inline PyTypeObject *SbkType< ::KCursor >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KCursor_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDateComboBox::Option >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KDateComboBox_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KDateComboBox::Option> >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_QFlags_KDateComboBox_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDateComboBox >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KDateComboBox_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDatePicker >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KDatePicker_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDatePickerPopup::Mode >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KDatePickerPopup_Mode_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KDatePickerPopup::Mode> >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_QFlags_KDatePickerPopup_Mode_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDatePickerPopup >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KDatePickerPopup_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDateTimeEdit::Option >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KDateTimeEdit_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KDateTimeEdit::Option> >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_QFlags_KDateTimeEdit_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDateTimeEdit >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KDateTimeEdit_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDragWidgetDecoratorBase >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KDragWidgetDecoratorBase_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDualAction >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KDualAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KEditListWidget::Button >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KEditListWidget_Button_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KEditListWidget::Button> >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_QFlags_KEditListWidget_Button_IDX]); }
template<> inline PyTypeObject *SbkType< ::KEditListWidget >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KEditListWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFontAction >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KFontAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFontChooser::FontColumn >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KFontChooser_FontColumn_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFontChooser::FontDiff >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KFontChooser_FontDiff_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KFontChooser::FontDiff> >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_QFlags_KFontChooser_FontDiff_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFontChooser::DisplayFlag >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KFontChooser_DisplayFlag_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KFontChooser::DisplayFlag> >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_QFlags_KFontChooser_DisplayFlag_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFontChooser::FontListCriteria >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KFontChooser_FontListCriteria_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFontChooser >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KFontChooser_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFontChooserDialog >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KFontChooserDialog_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFontRequester >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KFontRequester_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFontSizeAction >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KFontSizeAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KGradientSelector >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KGradientSelector_IDX]); }
template<> inline PyTypeObject *SbkType< ::KGuiItem >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KGuiItem_IDX]); }
template<> inline PyTypeObject *SbkType< ::KLed::State >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KLed_State_IDX]); }
template<> inline PyTypeObject *SbkType< ::KLed::Shape >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KLed_Shape_IDX]); }
template<> inline PyTypeObject *SbkType< ::KLed::Look >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KLed_Look_IDX]); }
template<> inline PyTypeObject *SbkType< ::KLed >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KLed_IDX]); }
template<> inline PyTypeObject *SbkType< ::KLineEditUrlDropEventFilter >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KLineEditUrlDropEventFilter_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMessageBox::ButtonCode >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMessageBox_ButtonCode_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMessageBox::DialogType >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMessageBox_DialogType_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMessageBox::Option >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMessageBox_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KMessageBox::Option> >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_QFlags_KMessageBox_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMessageBoxNotifyInterface >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMessageBoxNotifyInterface_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMessageDialog::ButtonType >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMessageDialog_ButtonType_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMessageDialog::Type >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMessageDialog_Type_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMessageDialog >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMessageDialog_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMessageWidget::MessageType >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMessageWidget_MessageType_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMessageWidget::Position >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMessageWidget_Position_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMessageWidget >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMessageWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMimeTypeChooser::Visuals >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMimeTypeChooser_Visuals_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMimeTypeChooser >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMimeTypeChooser_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMimeTypeChooserDialog >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMimeTypeChooserDialog_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMultiTabBar::KMultiTabBarPosition >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMultiTabBar_KMultiTabBarPosition_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMultiTabBar::KMultiTabBarStyle >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMultiTabBar_KMultiTabBarStyle_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMultiTabBar >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMultiTabBar_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMultiTabBarButton >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMultiTabBarButton_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMultiTabBarTab >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KMultiTabBarTab_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNewPasswordDialog >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KNewPasswordDialog_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNewPasswordWidget::PasswordStatus >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KNewPasswordWidget_PasswordStatus_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNewPasswordWidget::RevealPasswordMode >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KNewPasswordWidget_RevealPasswordMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNewPasswordWidget >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KNewPasswordWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPageDialog::FaceType >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPageDialog_FaceType_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPageDialog >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPageDialog_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPageModel::Role >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPageModel_Role_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPageModel >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPageModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPageView::FaceType >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPageView_FaceType_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPageView >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPageView_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPageWidget >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPageWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPageWidgetItem >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPageWidgetItem_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPageWidgetModel >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPageWidgetModel_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPassword::RevealMode >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPassword_RevealMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPasswordDialog::KPasswordDialogFlag >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPasswordDialog_KPasswordDialogFlag_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KPasswordDialog::KPasswordDialogFlag> >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_QFlags_KPasswordDialog_KPasswordDialogFlag_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPasswordDialog::ErrorType >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPasswordDialog_ErrorType_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPasswordDialog >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPasswordDialog_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPasswordLineEdit >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPasswordLineEdit_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPixmapRegionSelectorDialog >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPixmapRegionSelectorDialog_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPixmapRegionSelectorWidget::RotateDirection >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPixmapRegionSelectorWidget_RotateDirection_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPixmapRegionSelectorWidget >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPixmapRegionSelectorWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPixmapSequence >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPixmapSequence_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPixmapSequenceOverlayPainter >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPixmapSequenceOverlayPainter_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPixmapSequenceWidget >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPixmapSequenceWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPopupFrame >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KPopupFrame_IDX]); }
template<> inline PyTypeObject *SbkType< ::KRatingPainter >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KRatingPainter_IDX]); }
template<> inline PyTypeObject *SbkType< ::KRatingWidget >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KRatingWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::KRecentFilesMenu >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KRecentFilesMenu_IDX]); }
template<> inline PyTypeObject *SbkType< ::KRuler::MetricStyle >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KRuler_MetricStyle_IDX]); }
template<> inline PyTypeObject *SbkType< ::KRuler >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KRuler_IDX]); }
template<> inline PyTypeObject *SbkType< ::KSelectAction::ToolBarMode >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KSelectAction_ToolBarMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::KSelectAction >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KSelectAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KSelector >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KSelector_IDX]); }
template<> inline PyTypeObject *SbkType< ::KSeparator >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KSeparator_IDX]); }
template<> inline PyTypeObject *SbkType< ::KSplitterCollapserButton >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KSplitterCollapserButton_IDX]); }
template<> inline PyTypeObject *SbkType< ::KSqueezedTextLabel >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KSqueezedTextLabel_IDX]); }
template<> inline PyTypeObject *SbkType< ::KStandardGuiItem::BidiMode >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KStandardGuiItem_BidiMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::KStandardGuiItem::StandardItem >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KStandardGuiItem_StandardItem_IDX]); }
template<> inline PyTypeObject *SbkType< ::KTimeComboBox::Option >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KTimeComboBox_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KTimeComboBox::Option> >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_QFlags_KTimeComboBox_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::KTimeComboBox >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KTimeComboBox_IDX]); }
template<> inline PyTypeObject *SbkType< ::KTitleWidget::ImageAlignment >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KTitleWidget_ImageAlignment_IDX]); }
template<> inline PyTypeObject *SbkType< ::KTitleWidget::MessageType >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KTitleWidget_MessageType_IDX]); }
template<> inline PyTypeObject *SbkType< ::KTitleWidget >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KTitleWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::KToggleAction >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KToggleAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KToggleFullScreenAction >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KToggleFullScreenAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KToolBarLabelAction >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KToolBarLabelAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KToolBarPopupAction::PopupMode >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KToolBarPopupAction_PopupMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::KToolBarPopupAction >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KToolBarPopupAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KToolBarSpacerAction >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KToolBarSpacerAction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KToolTipWidget >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KToolTipWidget_IDX]); }
template<> inline PyTypeObject *SbkType< ::KTwoFingerSwipe >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KTwoFingerSwipe_IDX]); }
template<> inline PyTypeObject *SbkType< ::KTwoFingerSwipeRecognizer >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KTwoFingerSwipeRecognizer_IDX]); }
template<> inline PyTypeObject *SbkType< ::KTwoFingerTap >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KTwoFingerTap_IDX]); }
template<> inline PyTypeObject *SbkType< ::KTwoFingerTapRecognizer >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KTwoFingerTapRecognizer_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUrlLabel >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KUrlLabel_IDX]); }
template<> inline PyTypeObject *SbkType< ::KViewStateSerializer >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KViewStateSerializer_IDX]); }
template<> inline PyTypeObject *SbkType< ::KXYSelector >() { return Shiboken::Module::get(SbkKWidgetsAddonsTypeStructs[SBK_KXYSelector_IDX]); }

} // namespace Shiboken

QT_WARNING_POP
#endif // SBK_KWIDGETSADDONS_PYTHON_H

